@@ -2,6 +2,7 @@ import sqlalchemy as sa
 from sqlalchemy import PrimaryKeyConstraint
 from sqlalchemy.orm import relationship
 from tests import TestCase, create_test_cases
+from packaging import version as py_pkg_version
 
 
 class AssociationTableRelationshipsTestCase(TestCase):
@@ -17,8 +18,11 @@ class AssociationTableRelationshipsTestCase(TestCase):
 
             article_id = sa.Column(sa.Integer, sa.ForeignKey('article.id'))
             author_id = sa.Column(sa.Integer, sa.ForeignKey('author.id'))
-            author = relationship('Author')
-            article = relationship('Article')
+            relationship_kwargs = {}
+            if py_pkg_version.parse(sa.__version__) >= py_pkg_version.parse('1.4.0'):
+                relationship_kwargs.update({'overlaps': 'articles'})
+            author = relationship('Author', **relationship_kwargs)
+            article = relationship('Article', **relationship_kwargs)
 
         self.PublishedArticle = PublishedArticle
 
